import datacpp.pipeline as pipeline
import datacpp.libdatacpp as data

class data_batch:
    def __init__(self,file_name,label_name,image_dir,label_dir,batch_size,label_type,heatmap=False):
        self.label_type=label_type
        self.heatmap=heatmap
        self.pipe=pipeline.pipeline(batch_size,file_name,label_name,image_dir,label_dir,self.label_type,heatmap=self.heatmap)
    def init_batch(self):
        self.pipe.producer()
    def next_batch(self,i):
        return self.pipe.consumer(i)


import datacpp.dataloader as dataloader
import datacpp.libdatacpp as data
import numpy as np
import cv2
import time

if __name__=="__main__":
    label_type=data.LABEL_TYPE.DETECTION
    batch=dataloader.data_batch(label_type,False)
    batch.init_batch()
    for i in range(100):
        start=time.time()
        batch_data=batch.next_batch()
        end=time.time()
        print("time:{}--{}".format(i,end-start))
        if batch_data is None:
            batch.init_batch()
            continue
        images=batch_data[0]
        labels=batch_data[1]
        for i in range(len(images)):
            height,width,_=images[i].shape
            for j in range(len(labels[i])):
                box=labels[i][j]
                for t in range(4):
                    if t%2==0:
                        box[t]=int(box[t]*width)
                    else:
                        box[t]=int(box[t]*height)
                cv2.rectangle(images[i],(box[0],box[1]),(box[2],box[3]),(255,0,0),thickness=1)
                cv2.putText(images[i],str(box[4]),(box[0],box[1]),cv2.FONT_HERSHEY_SIMPLEX,1,(0,255,0))
            cv2.imshow("images:",images[i])
            cv2.waitKey(0)


import datacpp.libdatacpp as data
import numpy as np
import time
class pipeline:
    def __init__(self,batch_size,file_name,label_name,image_dir,label_dir,label_type,\
        label_postfix=".xml",image_type=".jpg",out_h=640,out_w=640,shuffle=True,\
        que_size=10,thread_num=4,heatmap=True,out_flag=False):
        self.batch_size=batch_size
        self.file_name=file_name
        self.label_name=label_name
        self.image_dir=image_dir
        self.label_dir=label_dir
        self.label_type=label_type
        self.label_postfix=label_postfix
        self.image_type=image_type
        self.out_h=out_h
        self.out_w=out_w
        self.shuffle=shuffle
        self.thread_num=thread_num
        self.heatmap=heatmap
        self.out_flag=out_flag

    def producer(self,): 
        self.batch_data=data.args_init(self.batch_size,self.out_h,self.out_w,self.image_dir,\
            self.label_dir,self.file_name,self.label_name,self.image_type,self.label_type,self.label_postfix,\
                self.heatmap, self.shuffle,self.thread_num,self.out_flag)
        data.start_producer(self.batch_data)
    def consumer(self,i):
        batch_size = self.batch_data.get_batch_size()
        epoch_size = self.batch_data.get_epoch_size()

        if((i+1)*batch_size>epoch_size):
            return None
        batch=data.next_batch_detection()
        return [batch.images,batch.box_labels]




from setuptools import setup,find_packages

setup(
    name='datacpp',
    version='0.6',
    packages=find_packages(),
    description="This is a torch data load package.",
    author="UCAS wang lishun",
    author_email="690332121@qq.com",
    url="https://github.com/wanlishun66668/datacpp",
    include_package_data=True
)